Correlation pattern recognizer (Copatrec) package.
For more information, please see the example and Document notebook.

# How to use Copatrec
To use Copatrec, it should be either cloned from GitHub, or
installed using the package files (pip and py providers will
be ready in the future)

## Recommended installation
It is recommended to install Copatrec using `pip` (see below).

## Installing using pip
To install Copatrec, please use the following code in your terminal:

```pip install copatrec```

## Cloning (copying) source code:
The source code is organized in a hierarchical structure to ease the creation of package files. 
Following convention, the source code can be found in the 'src' folder, and examples can be found in the 'examples' folder.

### Required packages to use Copatrec
If the package is installed from GitHub, then it would be suggested
to install the following packages (dependencies) in your system using `pip` or any other 
preferred approaches. 
- matplotlib
- NumPy
- pandas
- scipy
- sklearn

## Web application (On progress)
www.copatrec.org

# Examples

The "examples" folder can be found under the GitHub repo. Its direct URL is:

https://github.com/copatrec/copatrec/tree/master/examples

## SoftwareX.py
An example file with setups to reproduce paper results for SoftwareX journal.

## Tutorial files
There are two files in different formats (.py and .ipynb). For a detailed tutorial on Copatrec, the Jupyter
file (Document.ipynb) is recommended. 
